pub struct ElementDecl {
pub name: String,
pub type_name: Option<QName>,
pub inline_type: Option<Box<ComplexType>>,
}Expand description
Represents an element declaration in the schema, which can be either a global element or an inline element declaration inside a compositor.
Fields
name: StringThe name of the element.
type_name: Option<QName>The type of the element, if specified.
inline_type: Option<Box<ComplexType>>The inline complex type of the element, if specified.